Learn R Programming

log4r (version 0.5.0)

log4r-package: log4r: A Fast and Lightweight Logging System for R, Based on 'log4j'

Description

The log4r package is meant to provide a fast, lightweight, object-oriented approach to logging in R based on the widely-emulated 'log4j' system and etymology.

Arguments

Author

Maintainer: Hadley Wickham hadley@posit.co (ORCID)

Authors:

Other contributors:

  • Kenton White [contributor]

  • Kirill Müller krlmlr+r@mailbox.org [contributor]

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also