Learn R Programming

log4r (version 0.5.0)

logger: Create a logger

Description

This is the main interface for configuring logging behaviour. We adopt the well-known log4j etymology: Appenders are destinations (e.g. the console or a file) where logs are written, and the Layout is the format of these logs.

Usage

logger(threshold = "INFO", appenders = console_appender())

Value

An object of class "logger".

Arguments

threshold

The logging threshold, one of "DEBUG", "INFO", "WARN", "ERROR", or "FATAL". Logs with a lower severity than the threshold will be discarded.

appenders

The logging appenders; both single appenders and a list() of them are supported. See Appenders.

See Also

Appenders and Layouts for information on controlling the behaviour of the logger object.

Examples

Run this code
# By default, logs are written to the console at the "INFO" threshold.
logger <- logger()

log_info(logger, "Located nearest gas station.")
log_warn(logger, "Ez-Gas sensor network is not available.")
log_debug(logger, "Debug messages are suppressed by default.")

Run the code above in your browser using DataLab