Learn R Programming

log4r (version 0.5.0)

syslog_appender: Send logs to the local syslog

Description

Send messages to the local syslog. Requires the rsyslog package.

Usage

syslog_appender(identifier, layout = bare_log_layout(), ...)

Value

An appender: a function with the interface function(level, ...)

that writes its arguments to the local syslog and returns invisible(NULL).

Arguments

identifier

A string identifying the application.

layout

A layout function taking a level parameter and additional arguments corresponding to the message.

...

Further arguments passed on to rsyslog::open_syslog().

See Also

appenders for more information on Appenders.

Examples

Run this code
if (FALSE) {
# Send messages to the local syslog.
appender <- syslog_appender("my-application")
appender("INFO", "Message.")
}

Run the code above in your browser using DataLab