Learn R Programming

log4r (version 0.5.0)

tcp_appender: Send logs over TCP

Description

Append messages to arbitrary TCP destinations.

Usage

tcp_appender(
  host,
  port,
  layout = default_log_layout(),
  timeout = getOption("timeout")
)

Value

An appender: a function with the interface function(level, ...)

that writes its arguments to the socket and returns invisible(NULL).

Arguments

host

Hostname for the socket connection.

port

Port number for the socket connection.

layout

A layout function taking a level parameter and additional arguments corresponding to the message.

timeout

Timeout for the connection.

See Also

appenders for more information on Appenders, and base::socketConnection() for the underlying connection object used by tcp_appender().

Examples

Run this code
if (FALSE) {
# Send messages to a listener on localhost.
appender <- tcp_appender("localhost", port = 8080)
appender("INFO", "Message.")
}

Run the code above in your browser using DataLab