The log4r package is meant to provide a fast, lightweight, object-oriented approach to logging in R based on the widely-emulated 'log4j' system and etymology.
Maintainer: Hadley Wickham hadley@posit.co (ORCID)
Authors:
John Myles White [copyright holder]
Aaron Jacobs atheriel@gmail.com
Other contributors:
Kenton White [contributor]
Kirill Müller krlmlr+r@mailbox.org [contributor]
Posit Software, PBC (ROR) [copyright holder, funder]
Useful links: