powered by
Send messages to the local syslog. Requires the rsyslog package.
rsyslog
syslog_appender(identifier, layout = bare_log_layout(), ...)
An appender: a function with the interface function(level, ...)
function(level, ...)
that writes its arguments to the local syslog and returns invisible(NULL).
invisible(NULL)
A string identifying the application.
A layout function taking a level parameter and additional arguments corresponding to the message.
level
Further arguments passed on to rsyslog::open_syslog().
rsyslog::open_syslog()
appenders for more information on Appenders.
if (FALSE) { # Send messages to the local syslog. appender <- syslog_appender("my-application") appender("INFO", "Message.") }
Run the code above in your browser using DataLab